#include "customlabel.h"
#include <QDebug>
#include <QPalette>

customLabel::customLabel(QWidget *parent) : QLabel(parent)
{
    ID = -1;
    setAutoFillBackground(true);
}

void customLabel::enterEvent(QEvent *event)
{
    //qDebug() << "customLabel enter, id" << ID;
    grabKeyboard();
    QLabel::enterEvent(event);
}

void customLabel::leaveEvent(QEvent *event)
{
    //qDebug() << "customLabel leave, id" << ID;
    releaseKeyboard();
    emit sigHide();
    QLabel::leaveEvent(event);
}

void customLabel::keyPressEvent(QKeyEvent *event)
{
    if(event->key() == Qt::Key_M && !event->isAutoRepeat())
    {
        //qDebug() << "customLabel keyPress, id" << ID
        //         << "key" << event->key();
        emit sigKeyPressed(bgColor);
    }
    QLabel::keyPressEvent(event);
}

void customLabel::keyReleaseEvent(QKeyEvent *event)
{
    if(event->key() == Qt::Key_M && !event->isAutoRepeat())
    {
        //qDebug() << "customLabel keyRelease, id" << ID
        //         << "key" << event->key();
        emit sigHide();
    }
    QLabel::keyReleaseEvent(event);
}

int customLabel::getID() const
{
    return ID;
}

void customLabel::setID(int value)
{
    ID = value;
}

void customLabel::setBackgroundColor(const QColor &c)
{
    QPalette pal = palette();
    pal.setColor(QPalette::Background, c);
    setPalette(pal);
    bgColor = c;
}
