#include "labelcontainer.h"

labelContainer::labelContainer(QWidget *parent) : QWidget(parent)
{
    initObjects();
    initLayout();
}

void labelContainer::popup(const QColor &c)
{
    QPalette p = popupLabel->palette();
    p.setColor(QPalette::Background, c);
    popupLabel->setPalette(p);
    popupLabel->show();
}

void labelContainer::hidePopup()
{
    popupLabel->hide();
}

void labelContainer::initObjects()
{
    mLbl = new QLabel("Enter text", this);
    mLineEdit = new QLineEdit(this);

    popupLabel = new QLabel(); // we won't add this to layout
    popupLabel->setFixedSize(100,100);
    popupLabel->setAutoFillBackground(true);
    popupLabel->hide();

    for(int i=0; i < 3; ++i)
    {
        customLabel* cLbl = new customLabel(this);
        connect(cLbl, &customLabel::sigKeyPressed,
                this, &labelContainer::popup);
        connect(cLbl, &customLabel::sigHide,
                this, &labelContainer::hidePopup);
        cLbl->setText(QString("Label ") + QString::number(i));
        cLbl->setID(i);
        QColor c;
        switch(i)
        {
        case 0:
            c = QColor(255,128,128);
            break;
        case 1:
            c = QColor(128,255,128);
            break;
        case 2:
            c = QColor(128,128,255);
            break;
        }
        cLbl->setBackgroundColor(c);
        mCustomLblVec.append(cLbl);
    }
}

void labelContainer::initLayout()
{
    QHBoxLayout* hb = new QHBoxLayout();
    hb->addWidget(mLbl);
    hb->addWidget(mLineEdit);

    QVBoxLayout* vb = new QVBoxLayout();
    vb->addItem(hb);
    for(auto clbl : mCustomLblVec)
    {
        vb->addWidget(clbl);
    }

    setLayout(vb);
}
